@@ -6,13 +6,14 @@ from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Type,
 
 from graphql import GraphQLResolveInfo
 
-from strawberry.arguments import convert_arguments
+from strawberry.arguments import UNSET, convert_arguments
 from strawberry.types.info import Info
 from strawberry.utils.typing import get_parameters, has_type_var, is_type_var
 
+from .arguments import StrawberryArgument
 from .permission import BasePermission
 from .types.fields.resolver import StrawberryResolver
-from .types.types import ArgumentDefinition, FederationFieldParams, undefined
+from .types.types import FederationFieldParams
 from .union import StrawberryUnion
 from .utils.str_converters import to_camel_case
 
@@ -37,24 +38,30 @@ class StrawberryField(dataclasses.Field):
         description: Optional[str] = None,
         base_resolver: Optional[StrawberryResolver] = None,
         permission_classes: List[Type[BasePermission]] = (),  # type: ignore
-        default_value: Any = undefined,
+        default_value: Any = UNSET,
+        default_factory: Union[Callable, object] = UNSET,
         deprecation_reason: Optional[str] = None,
     ):
         federation = federation or FederationFieldParams()
 
+        # basic fields are fields with no provided resolver
+        is_basic_field = not base_resolver
+
         super().__init__(  # type: ignore
-            default=dataclasses.MISSING,
-            default_factory=dataclasses.MISSING,
-            init=base_resolver is None,
-            repr=True,
+            default=(default_value if default_value != UNSET else dataclasses.MISSING),
+            default_factory=(
+                default_factory if default_factory != UNSET else dataclasses.MISSING
+            ),
+            init=is_basic_field,
+            repr=is_basic_field,
+            compare=is_basic_field,
             hash=None,
-            compare=True,
             metadata=None,
         )
 
         self._graphql_name = graphql_name
         if python_name is not None:
-            self.name = python_name
+            self.python_name = python_name
         if type_ is not None:
             # TODO: Clean up the typing around StrawberryField.type
             self.type = typing.cast(type, type_)
@@ -94,7 +101,7 @@ class StrawberryField(dataclasses.Field):
         return self
 
     @property
-    def arguments(self) -> List[ArgumentDefinition]:
+    def arguments(self) -> List[StrawberryArgument]:
         if not self.base_resolver:
             return []
 
@@ -103,9 +110,9 @@ class StrawberryField(dataclasses.Field):
     @property
     def graphql_name(self) -> Optional[str]:
         if self._graphql_name:
-            return to_camel_case(self._graphql_name)
-        if self.name:
-            return to_camel_case(self.name)
+            return self._graphql_name
+        if self.python_name:
+            return to_camel_case(self.python_name)
         if self.base_resolver:
             return to_camel_case(self.base_resolver.name)
         return None
@@ -114,6 +121,10 @@ class StrawberryField(dataclasses.Field):
     def python_name(self) -> str:
         return self.name
 
+    @python_name.setter
+    def python_name(self, name: str) -> None:
+        self.name = name
+
     @property
     def base_resolver(self) -> Optional[StrawberryResolver]:
         return self._base_resolver
@@ -123,8 +134,9 @@ class StrawberryField(dataclasses.Field):
         self._base_resolver = resolver
         self.origin = resolver.wrapped_func
 
-        # Don't add field to __init__ or __repr__ once it has a resolver
+        # Don't add field to __init__, __repr__ and __eq__ once it has a resolver
         self.init = False
+        self.compare = False
         self.repr = False
 
         # TODO: See test_resolvers.test_raises_error_when_argument_annotation_missing
@@ -272,6 +284,8 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     federation: Optional[FederationFieldParams] = None,
     deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable, object] = UNSET,
 ) -> StrawberryField:
     """Annotates a method or property as a GraphQL field.
 
@@ -297,6 +311,8 @@ def field(
         permission_classes=permission_classes or [],
         federation=federation or FederationFieldParams(),
         deprecation_reason=deprecation_reason,
+        default_value=default,
+        default_factory=default_factory,
     )
 
     if resolver:
