@@ -4,6 +4,8 @@ import typing
 from typing import Dict, List, Type, cast
 
 from strawberry.exceptions import (
+    FieldWithResolverAndDefaultFactoryError,
+    FieldWithResolverAndDefaultValueError,
     MissingTypesForGenericError,
     PrivateStrawberryFieldError,
 )
@@ -25,8 +27,8 @@ from strawberry.utils.typing import (
     is_union,
 )
 
+from ..arguments import UNSET, StrawberryArgument
 from .generics import copy_type_with, get_name_from_types
-from .types import ArgumentDefinition, undefined
 
 
 def _resolve_generic_type(type: Type, field_name: str) -> Type:
@@ -171,25 +173,25 @@ def resolve_type_field(field: StrawberryField) -> None:
         field.is_union = True
 
 
-def _resolve_type(argument_definition: ArgumentDefinition) -> None:
+def _resolve_type(argument: StrawberryArgument) -> None:
     # TODO: This should be handled by StrawberryType in the future
     # Convert a python type to include a strawberry definition, so for example
     # Union becomes a class with a UnionDefinition, Generics become an actual
     # type definition. This helps with making the code to convert the type definitions
     # to GraphQL types, as we only have to deal with Python's typings in one place.
 
-    type = cast(Type, argument_definition.type)
-    origin_name = cast(str, argument_definition.origin_name)
+    type = cast(Type, argument.type)
+    assert argument.python_name
 
     if isinstance(type, str):
-        module = sys.modules[argument_definition.origin.__module__].__dict__
+        module = sys.modules[argument.origin.__module__].__dict__
 
         type = eval(type, module)
-        argument_definition.type = type
+        argument.type = type
 
     if isinstance(type, LazyType):
-        argument_definition.type = type.resolve_type()
-        type = cast(Type, argument_definition.type)
+        argument.type = type.resolve_type()
+        type = cast(Type, argument.type)
 
     if is_forward_ref(type):
         # if the type is a forward reference we try to resolve the type by
@@ -200,12 +202,12 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
 
         type_name = type.__forward_arg__
 
-        module = sys.modules[argument_definition.origin.__module__]
+        module = sys.modules[argument.origin.__module__]
 
         # TODO: we should probably raise an error if we can't find the type
         type = module.__dict__[type_name]
 
-        argument_definition.type = type
+        argument.type = type
 
         return
 
@@ -214,9 +216,9 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
 
         # async generators are used in subscription, we only need the yield type
         # https://docs.python.org/3/library/typing.html#typing.AsyncGenerator
-        argument_definition.type = get_async_generator_annotation(type)
+        argument.type = get_async_generator_annotation(type)
 
-        return _resolve_type(argument_definition)
+        return _resolve_type(argument)
 
     # check for Optional[A] which is represented as Union[A, None], we
     # have an additional check for proper unions below
@@ -227,13 +229,11 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
         # the field is only optional if it is not a list or if it was already optional
         # since we mark the child as optional when the field is a list
 
-        argument_definition.is_optional = (
-            True and not argument_definition.is_list or argument_definition.is_optional
-        )
-        argument_definition.is_child_optional = argument_definition.is_list
-        argument_definition.type = get_optional_annotation(type)
+        argument.is_optional = True and not argument.is_list or argument.is_optional
+        argument.is_child_optional = argument.is_list
+        argument.type = get_optional_annotation(type)
 
-        return _resolve_type(argument_definition)
+        return _resolve_type(argument)
 
     elif is_list(type):
         # TODO: maybe this should be an argument definition when it is argument
@@ -241,14 +241,14 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
         child_field = StrawberryField(
             python_name=None,
             graphql_name=None,
-            origin=argument_definition.origin,  # type: ignore
+            origin=argument.origin,  # type: ignore
             type_=get_list_annotation(type),
         )
         resolve_type_field(child_field)
 
-        argument_definition.type = None
-        argument_definition.is_list = True
-        argument_definition.child = cast(ArgumentDefinition, child_field)
+        argument.type = None
+        argument.is_list = True
+        argument.child = cast(StrawberryArgument, child_field)
 
         return
 
@@ -258,7 +258,7 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
         # Optional[Union[A, B]] is represented as Union[A, B, None] so we need
         # too check again if the field is optional as the check above only checks
         # for single Optionals
-        argument_definition.is_optional = is_optional(type)
+        argument.is_optional = is_optional(type)
 
         types = type.__args__
 
@@ -266,13 +266,13 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
         # are simpler and cannot contain lists or optionals
 
         types = tuple(
-            _resolve_generic_type(t, origin_name)
+            _resolve_generic_type(t, argument.python_name)
             for t in types
             if t is not None.__class__
         )
 
-        argument_definition.is_union = True
-        argument_definition.type = union(get_name_from_types(types), types)
+        argument.is_union = True
+        argument.type = union(get_name_from_types(types), types)
 
     # case for Type[A], we want to convert generics to have the concrete types
     # when we pass them, so that we don't have to deal with generics when
@@ -288,16 +288,16 @@ def _resolve_type(argument_definition: ArgumentDefinition) -> None:
         # >>> a: X[str]
 
         if len(args) == 0:
-            name = cast(str, argument_definition.origin_name)
+            assert argument.python_name
 
-            raise MissingTypesForGenericError(name, type)
+            raise MissingTypesForGenericError(argument.python_name, type)
 
         # we only make a copy when all the arguments are not type vars
         if not all(is_type_var(a) for a in args):
-            argument_definition.type = copy_type_with(type, *args)
+            argument.type = copy_type_with(type, *args)
 
     if isinstance(type, StrawberryUnion):
-        argument_definition.is_union = True
+        argument.is_union = True
 
 
 def _get_type_params(fields: List[StrawberryField]) -> Dict[str, Type]:
@@ -380,6 +380,23 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
             if isinstance(field.type, Private):
                 raise PrivateStrawberryFieldError(field.python_name, cls.__name__)
 
+            # Check that default is not set if a resolver is defined
+            if field.default != dataclasses.MISSING and field.base_resolver is not None:
+                raise FieldWithResolverAndDefaultValueError(
+                    field.python_name, cls.__name__
+                )
+
+            # Check that default_factory is not set if a resolver is defined
+            # Note: using getattr because of this issue:
+            # https://github.com/python/mypy/issues/6910
+            if (
+                getattr(field, "default_factory") != dataclasses.MISSING  # noqa
+                and field.base_resolver is not None
+            ):
+                raise FieldWithResolverAndDefaultFactoryError(
+                    field.python_name, cls.__name__
+                )
+
             # we make sure that the origin is either the field's resolver when
             # called as:
             #
@@ -405,7 +422,7 @@ def _get_fields(cls: Type) -> List[StrawberryField]:
                 graphql_name=to_camel_case(field.name),
                 type_=field_type,
                 origin=cls,
-                default_value=getattr(cls, field.name, undefined),
+                default_value=getattr(cls, field.name, UNSET),
             )
 
         field_name = field.graphql_name
