@@ -1,7 +1,5 @@
 import dataclasses
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
-
-from strawberry.union import StrawberryUnion
+from typing import TYPE_CHECKING, Dict, List, Optional, Type
 
 
 if TYPE_CHECKING:
@@ -51,22 +49,6 @@ class TypeDefinition:
         return self._type_params
 
 
-@dataclasses.dataclass
-class ArgumentDefinition:
-    name: Optional[str] = None
-    origin_name: Optional[str] = None
-    type: Optional[Union[Type, StrawberryUnion]] = None
-    origin: Optional[Type] = None
-    child: Optional["ArgumentDefinition"] = None
-    is_subscription: bool = False
-    is_optional: bool = False
-    is_child_optional: bool = False
-    is_list: bool = False
-    is_union: bool = False
-    description: Optional[str] = None
-    default_value: Any = undefined
-
-
 @dataclasses.dataclass
 class FederationFieldParams:
     provides: List[str] = dataclasses.field(default_factory=list)
